<?php

add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_theme_mode', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );
add_filter( 'ot_use_theme_options', '__return_true' );
add_filter( 'ot_meta_boxes', '__return_true' );

include get_template_directory() . '/admin/theme-options.php';
include get_template_directory() . '/admin/meta-boxes.php';
include get_template_directory() . '/admin/options.php';
include get_template_directory() . '/admin/widgets.php';
include get_template_directory() . '/admin/customcss.php';
include get_template_directory() . '/admin/builder_output.php';
include get_template_directory() . '/admin/builder_settings.php';
require_once( ABSPATH . 'wp-admin/includes/media.php' );

/* ----------------------------------------------------- */
/* Theme Install */
/* ----------------------------------------------------- */

function manggis_theme_admin_bar_menu($admin_bar) {
  if ( function_exists('ot_get_option') ) {
    if (!is_super_admin() || !is_admin_bar_showing())
      return;
    $admin_bar->add_menu(array(
      'id' => 'option_tree_link',
      'title' => esc_html__("Theme Options", 'manggis'),
      'href' => site_url().'/wp-admin/themes.php?page=ot-theme-options',
      'meta' => array()
    ));
  }
}

add_action('after_setup_theme', 'manggis_install');
add_action('admin_bar_menu', 'manggis_theme_admin_bar_menu', 99);

if (!function_exists('manggis_install')):

  function manggis_install() {
    add_theme_support('automatic-feed-links');
		add_theme_support( 'title-tag' );
    add_theme_support( 'woocommerce' );
    add_theme_support( 'align-wide' );
		add_theme_support('post-formats', array( 'gallery', 'quote', 'link'));
		add_editor_style( 'assets/css/editor-style.min.css' );
		register_nav_menu( 'menu-header', 'Header menu' );
		load_theme_textdomain( 'manggis', get_template_directory() . '/languages' );
	}

endif;

if ( ! isset( $content_width ) ) {
	$content_width = 1800;
}

/* ----------------------------------------------------- */
/* Scripts */
/* ----------------------------------------------------- */

function manggis_scripts() {

  wp_enqueue_script( 'touchSwipe', get_template_directory_uri() . '/assets/js/jquery.touchSwipe.min.js', array( 'jquery' ), false, true );
  wp_enqueue_script( 'appear', get_template_directory_uri() . '/assets/js/jquery.appear.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'carousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'easing', get_template_directory_uri() . '/assets/js/jquery.easing.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'justifiedGallery', get_template_directory_uri() . '/assets/js/jquery.justifiedGallery.min.js', array( 'jquery' ), false, true );
  wp_enqueue_script( 'manggis-masonry', get_theme_file_uri( '/assets/js/masonry.min.js' ), array( 'jquery' ), false, true );
  wp_enqueue_script( 'imagesloaded' );
	wp_enqueue_script( 'custom', get_template_directory_uri() . '/assets/js/custom.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/assets/js/fancybox.js', array( 'jquery' ), false, true );
  // wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/assets/js/fitvids.js', array( 'jquery' ), false, true );
  wp_enqueue_script( 'heroslider', get_template_directory_uri() . '/assets/js/heroslider.min.js', array( 'jquery' ), false, true );
  wp_enqueue_script( 'timeline', get_template_directory_uri() . '/assets/js/timeline.min.js', array( 'jquery' ), false, true );
  wp_localize_script( 'custom', 'infinite_url', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

	if ( function_exists('ot_get_option') && ot_get_option('preloader_on') != "off") {
		wp_enqueue_script( 'lazyload', get_template_directory_uri() . '/assets/js/lazyload.min.js', array( 'jquery' ), false, true );
	}

	if (is_singular()) {
		wp_enqueue_script('comment-reply');
	}

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/font/css/font-awesome.min.css', array(), '4.3' );
	wp_enqueue_style( 'justifiedGallery', get_template_directory_uri() . '/assets/css/justifiedGallery.min.css', array(), '4.3' );
	wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/assets/css/fancybox.min.css', array(), '4.3' );
  wp_enqueue_style( 'owl-transitions', get_template_directory_uri() . '/assets/css/owl.transitions.min.css');
  // wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.min.css' );
	wp_enqueue_style( 'style', get_stylesheet_uri() );
  wp_enqueue_style( 'style-adaptive', get_template_directory_uri() . '/assets/css/style-adaptive.min.css' );

  if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    wp_enqueue_style( 'woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.min.css' );
  }

}
add_action( 'wp_enqueue_scripts', 'manggis_scripts' );

if (!function_exists('manggis_styles')) {
	function manggis_styles() {
		wp_register_style('responsive', get_template_directory_uri() . '/assets/css/responsive.min.css', '', '', 'screen');
		wp_enqueue_style('responsive');
	}
	add_action('wp_enqueue_scripts', 'manggis_styles');
}

function manggis_admin_style() {
  wp_enqueue_style('fix-ot-styles', get_template_directory_uri() . '/assets/css/fix-ot-styles.min.css' );
}
add_action('admin_enqueue_scripts', 'manggis_admin_style');

/* ----------------------------------------------------- */
/* Google fonts */
/* ----------------------------------------------------- */

function manggis_fonts_url() {
  $font_url = '';

  /* Translators: If there are characters in your language that are not supported
  by chosen font(s), translate this to 'off'. Do not translate into your own language. */

  if ( 'off' !== _x( 'on', 'Google font: on or off', 'manggis' ) ) {
    $font_url = add_query_arg( 'family', urlencode( 'Work Sans:200,300,400,500,600,700|Montserrat:regular,700' ), "//fonts.googleapis.com/css" );
  }
  return $font_url;
}

function manggis_fonts_init() {
  wp_enqueue_style( 'Google-font', manggis_fonts_url(), array(), '1.0.0' );
}

add_action( 'wp_enqueue_scripts', 'manggis_fonts_init' );

/* ----------------------------------------------------- */
/* WooCommerce */
/* ----------------------------------------------------- */

remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

add_action('woocommerce_before_main_content', 'my_theme_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'my_theme_wrapper_end', 10);

function my_theme_wrapper_start() {
  echo '<section id="main">';
}

function my_theme_wrapper_end() {
  echo '</section>';
}

function manggis_wc_cart_count() {

  if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    $count = WC()->cart->cart_contents_count; ?>

    <a class="cart-contents" href="#" title="<?php esc_html_e( 'View your shopping cart', 'manggis' ); ?>">

      <?php if ( $count > 0 ) { ?>
        <span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
      <?php } ?>
    </a>

  <?php }
}

function manggis_add_to_cart_fragment( $fragments ) {
  ob_start();
  $count = WC()->cart->cart_contents_count; ?>

  <a class="cart-contents" href="#" title="<?php esc_html_e( 'View your shopping cart', 'manggis' ); ?>">
    <?php if ( $count > 0 ) { ?>
      <span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
    <?php } ?>
  </a>

  <?php $fragments['a.cart-contents'] = ob_get_clean();
  return $fragments;
}

add_filter( 'woocommerce_add_to_cart_fragments', 'manggis_add_to_cart_fragment' );
add_filter( 'woocommerce_show_page_title' , 'manggis_hide_page_title' );

function manggis_hide_page_title() {
  return false;
}

function manggis_add_to_minicart_fragment( $fragments ) {
  ob_start();
  $count = WC()->cart->cart_contents_count; ?>
  <div id="minicart_header" class="minicart-header widget_shopping_cart">
    <?php if ( $count > 0 ) { ?>
      <?php woocommerce_mini_cart(); ?>
    <?php } else { ?>
      <ul class="cart_list product_list_widget">
        <li class="empty"><?php _e( 'No products in the cart.', 'manggis' ); ?></li>
      </ul>
    <?php } ?>
  </div>

  <?php $fragments['div.minicart-header'] = ob_get_clean();
  return $fragments;
}

add_filter( 'woocommerce_add_to_cart_fragments', 'manggis_add_to_minicart_fragment' );

/* ----------------------------------------------------- */
/* Show submenu only */
/* ----------------------------------------------------- */

add_filter( 'wp_nav_menu_objects', 'manggis_submenu_limit', 10, 2 );

function manggis_submenu_limit( $items, $args ) {
  if ( empty($args->submenu) )
    return $items;
  $dest = wp_filter_object_list( $items, array( 'title' => $args->submenu ), 'and', 'ID' );
  $parent_id = array_pop( $dest );
  $children  = manggis_submenu_get_children_ids( $parent_id, $items );
  foreach ( $items as $key => $item ) {
    if ( ! in_array( $item->ID, $children ) )
      unset($items[$key]);
    }
  return $items;
}

function manggis_submenu_get_children_ids( $id, $items ) {
  $ids = wp_filter_object_list( $items, array( 'menu_item_parent' => $id ), 'and', 'ID' );
  foreach ( $ids as $id ) {
    $ids = array_merge( $ids, manggis_submenu_get_children_ids( $id, $items ) );
  }
  return $ids;
}

/* ----------------------------------------------------- */
/* Thumbs */
/* ----------------------------------------------------- */

  add_theme_support('post-thumbnails');
  // set_post_thumbnail_size(600, 300, true);
	add_image_size('manggis_blog-main', 800, 0, true);
	add_image_size('manggis_portfolio-main', 800, 800, true);
	add_image_size('manggis_portfolio-footer', 85, 85, true);

/* ----------------------------------------------------- */
/* Sidebars */
/* ----------------------------------------------------- */

function manggis_sidebars() {
	register_sidebar( array(
		'name' 			=> esc_html__('Default sidebar', 'manggis'),
		'id' 			=> 'manggis_sidebar1',
    'description'   => esc_html__('Sidebar used for all pages by default', 'manggis'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Contact Page sidebar', 'manggis'),
		'id' 			=> 'manggis_sidebar2',
    'description'   => esc_html__('Sidebar used only for Contact page template', 'manggis'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

  register_sidebar( array(
    'name' 			=> esc_html__('Footer 1', 'manggis'),
    'id' 			=> 'manggis_footer1',
    'description'   => esc_html__('Footer Sidebar in Left position', 'manggis'),
    'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
    'after_widget'	=> '</aside>',
    'before_title'	=> '<h6 class="widget-title"><span>',
    'after_title'	=> '</span></h6>',
  ) );

  register_sidebar( array(
    'name' 			=> esc_html__('Footer 2', 'manggis'),
    'id' 			=> 'manggis_footer2',
    'description'   => esc_html__('Footer Sidebar in Center position', 'manggis'),
    'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
    'after_widget'	=> '</aside>',
    'before_title'	=> '<h6 class="widget-title"><span>',
    'after_title'	=> '</span></h6>',
  ) );

  register_sidebar( array(
    'name' 			=> esc_html__('Footer 3', 'manggis'),
    'id' 			=> 'manggis_footer3',
    'description'   => esc_html__('Footer Sidebar in Right position', 'manggis'),
    'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
    'after_widget'	=> '</aside>',
    'before_title'	=> '<h6 class="widget-title"><span>',
    'after_title'	=> '</span></h6>',
  ) );

  register_sidebar( array(
    'name' 			=> esc_html__('Footer 1/2 Left', 'manggis'),
    'id' 			=> 'manggis_footer_sidebar1',
    'description'   => esc_html__('Footer Sidebar Left for copyright or menu', 'manggis'),
    'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
    'after_widget'	=> '</aside>',
    'before_title'	=> '<h6 class="widget-title"><span>',
    'after_title'	=> '</span></h6>',
  ) );

	register_sidebar( array(
		'name' 			=> esc_html__('Footer 1/2 Right', 'manggis'),
		'id' 			=> 'manggis_footer_sidebar2',
    'description'   => esc_html__('Footer Sidebar Right for copyright or menu', 'manggis'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

  register_sidebar( array(
		'name' 			=> esc_html__('WooCommerce', 'manggis'),
		'id' 			=> 'manggis_woocommerce_sidebar',
    'description'   => esc_html__('Sidebar which appear in Shop', 'manggis'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );
};

add_action( 'widgets_init', 'manggis_sidebars' );

/* ----------------------------------------------------- */
/* Option Tree Settings */
/* ----------------------------------------------------- */

function ot_recognized_font_families( $field_id = '' ) {
  $families = array();
  return apply_filters( 'ot_recognized_font_families', $families, $field_id );
}

/* ----------------------------------------------------- */
/* Comments Setup */
/* ----------------------------------------------------- */

function manggis_wrap_comment_text($content) {
  return "<div class=\"comment-content\"><p>". $content ."</p></div>";
}
add_filter('comment_text', 'manggis_wrap_comment_text');

/* ----------------------------------------------------- */
/* Tag Cloud */
/* ----------------------------------------------------- */

function manggis_tag_cloud_widget($args) {
  $args['largest'] = 14;
  $args['smallest'] = 14;
  $args['unit'] = 'px';
  return $args;
}

add_filter( 'widget_tag_cloud_args', 'manggis_tag_cloud_widget' );

/* ----------------------------------------------------- */
/* Getting global options */
/* ----------------------------------------------------- */

class manggis_GetGlobal {
  function __construct() {
    global $non_fullwidth, $columns, $masonry, $manggis_shared, $enable_mixed;
    $this->columns = $columns;
    $this->non_fullwidth = $non_fullwidth;
    $this->masonry = $masonry;
    $this->manggis_shared = $manggis_shared;
    $this->enable_mixed = $enable_mixed;
  }
}

/* ----------------------------------------------------- */
/* Slider */
/* ----------------------------------------------------- */

function manggis_slider() {

  $paged = 1;
  $exclude = $slider_navigation = $image_url = '';

  $portfolio_sorting = (function_exists('ot_get_option') && ot_get_option('portfolio_sorting')) ? esc_attr(ot_get_option('portfolio_sorting')) : '';
  $portfolio_order = (function_exists('ot_get_option') && ot_get_option('portfolio_order')) ? esc_attr(ot_get_option('portfolio_order')) : '';

  if ( get_query_var( 'paged' ) ) $paged = get_query_var( 'paged' );
  if ( get_query_var( 'page' ) ) $paged = get_query_var( 'page' );

  $slider_query_args = array(
    'post_type' => 'portfolio',
    'orderby' => $portfolio_sorting,
    'order' => $portfolio_order,
    'post__not_in' => array($exclude),
    'paged' => $paged,
    'posts_per_page' => 5,
    'meta_query' => array(
      array(
      'key' => '_thumbnail_id',
      'compare' => 'EXISTS'
      ),
      array(
        'key' => 'manggis_in_slider',
        'value' => 'on'
      ),
      array(
        'key' => 'manggis_page_slider',
        'value' => get_the_ID()
      )
    )
  );

  $slider_query = new WP_Query( $slider_query_args );

  if ($slider_query->have_posts()) { $i = 0; ?>

    <section class="cd-hero">
      <ul class="cd-hero-slider">

      <?php while ( $slider_query->have_posts() && $i < 6 ) : $slider_query->the_post(); $i++;
        $thumbnail_url = get_the_permalink();

        $slide_url = ( get_post_meta(get_the_ID(), 'manggis_slider_title_link', true) == 'off' ) ? '#' : get_the_permalink();
        $link_class = ( get_post_meta(get_the_ID(), 'manggis_slider_title_link', true) == 'off' ) ? 'no-link' : '';

        $slider_type = ( get_post_meta(get_the_ID(), 'manggis_slider_type', true) == 'cd-full-width' || get_post_meta(get_the_ID(), 'manggis_slider_type', true) == 'cd-half-width' ) ? get_post_meta(get_the_ID(), 'manggis_slider_type', true) : 'cd-full-width';
        $slider_text = (get_post_meta(get_the_ID(), 'manggis_slider_text', true)) ? get_post_meta(get_the_ID(), 'manggis_slider_text', true) : wp_trim_words( get_the_content(), 15 );

        if (has_post_thumbnail() && !post_password_required()) {
        	$portfolio_main = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), "full" );
        	$ratio = ($portfolio_main[2] > 0) ? $portfolio_main[1]/$portfolio_main[2] : '';
        	$image_url = $portfolio_main[0];
        } ?>

        <?php $slider_class = ( get_post_meta(get_the_ID(), 'manggis_slider_type', true) == 'cd-bg-video' ) ? 'cd-bg-video' : ''; ?>

        <?php if ( 1 == $i ) { $slider_class .= ' selected'; } ?>

        <li class="<?php echo esc_attr($slider_class); ?>"
          <?php if ( get_post_meta(get_the_ID(), 'manggis_slider_type', true) != 'cd-bg-video' ) { ?>
            style="background-image: url('<?php echo $slider_image = (get_post_meta(get_the_ID(), "manggis_slider_image", true)) ? esc_url(get_post_meta(get_the_ID(), "manggis_slider_image", true)) : esc_url($image_url); ?>');"
          <?php } ?>
          >
          <div class="<?php echo esc_html($slider_type) ?>">
            <div class="slider_heading">
            <h2><a href="<?php echo esc_url($slide_url); ?>" class="<?php echo esc_html($link_class); ?>"><?php the_title(); ?></a></h2>
            <p><?php echo esc_attr($slider_text); ?></p>
            <?php if (get_post_meta(get_the_ID(), 'manggis_slider_button1', true)) {
              echo '<a href="',
              $slider_button1url = (get_post_meta(get_the_ID(), 'manggis_slider_button1url', true)) ? esc_url(get_post_meta(get_the_ID(), 'manggis_slider_button1url', true)) : esc_url(get_the_permalink()),
              '" class="cd-btn">' . esc_attr(get_post_meta(get_the_ID(), 'manggis_slider_button1', true)) . '</a>';
            }
            if (get_post_meta(get_the_ID(), 'manggis_slider_button2', true)) {
              echo '<a href="',
              $slider_button2url = (get_post_meta(get_the_ID(), 'manggis_slider_button2url', true)) ? esc_url(get_post_meta(get_the_ID(), 'manggis_slider_button2url', true)) : esc_url(get_the_permalink()),
              '" class="cd-btn secondary">' . esc_attr(get_post_meta(get_the_ID(), 'manggis_slider_button2', true)) . '</a>';
            } ?>
            </div>
          </div>
          <?php if ( get_post_meta(get_the_ID(), 'manggis_slider_type', true) == 'cd-bg-video' ) { ?>
            <div class="cd-bg-video-wrapper" data-video="<?php echo esc_url(preg_replace('/\\.[^.\\s]{3,4}$/', '', get_post_meta(get_the_ID(), "manggis_slider_image", true))); ?>"></div>
          <?php } ?>
        </li>

     		<?php $slider_navigation .= '<li><span>' . get_the_title() . '</span></li>';	?>

      <?php endwhile; wp_reset_postdata(); ?>

    	</ul>
      <?php if (get_post_meta(get_the_ID(), 'manggis_slider_nav', true) != 'off') { ?>
      	<div class="cd-slider-nav">
      		<nav>
      			<span class="cd-marker item-1"></span>
      			<ul>
              <?php echo $slider_navigation; ?>
      			</ul>
      		</nav>
      	</div>
      <?php } ?>
    </section>

  <?php }
}

function manggis_carousel_slider() {

  $portfolio_sorting = (function_exists('ot_get_option') && ot_get_option('portfolio_sorting')) ? esc_attr(ot_get_option('portfolio_sorting')) : '';
  $portfolio_order = (function_exists('ot_get_option') && ot_get_option('portfolio_order')) ? esc_attr(ot_get_option('portfolio_order')) : '';

  $slider_query_args = array(
    'post_type' => 'portfolio',
    'orderby' => $portfolio_sorting,
    'order' => $portfolio_order,
    'meta_query' => array(
      array(
      'key' => '_thumbnail_id',
      'compare' => 'EXISTS'
      ),
      array(
        'key' => 'manggis_in_slider',
        'value' => 'on'
      ),
      array(
        'key' => 'manggis_page_slider',
        'value' => get_the_ID()
      )
    )
  );

  $slider_query = new WP_Query( $slider_query_args );

  if ($slider_query->have_posts()) { ?>

    <div class="fullscreen-slider">
    	<div class="owl-carousel owl-autoplay">

        <?php while ($slider_query->have_posts()) : $slider_query->the_post();

          $portfolio_main = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
      		$image_url = $portfolio_main[0];
      		$slide_title = get_the_title();
          $slide_url = (get_post_meta(get_the_ID(), 'manggis_show_aslightbox', true) == 'on') ? $portfolio_main[0] : get_the_permalink();
          $slide_url = (get_post_meta(get_the_ID(), 'manggis_customurl', TRUE)) ?: $slide_url;
      		$slide_url = ( get_post_meta(get_the_ID(), 'manggis_slider_title_link', true) == 'off' ) ? '#' : $slide_url;
          $link_class = ( get_post_meta(get_the_ID(), 'manggis_slider_title_link', true) == 'off' ) ? 'no-link' : '';
        	$ratio = ($portfolio_main[2] > 0) ? $portfolio_main[1]/$portfolio_main[2] : '';
      		$slide_subtitle = get_post_meta(get_the_ID(), 'manggis_slider_text', true); ?>

          <a class="slick-slide <?php echo esc_html($link_class); ?>" href="<?php echo esc_url($slide_url); ?>" <?php if ( get_post_meta(get_the_ID(), 'manggis_slider_title_link', true) != 'off' && get_post_meta(get_the_ID(), 'manggis_show_aslightbox', true) == 'on' ) { echo 'id="group"'; } ?>>
            <div class="fullscreen-title">
              <div id="page-title">
                <h1><?php echo esc_html($slide_title); ?></h1>
                <?php if ( $slide_subtitle ) { ?>
                  <div class="subtitle">
                    <p><?php echo esc_html($slide_subtitle); ?></p>
                  </div>
                <?php } ?>
              </div>
            </div>
            <img src="<?php echo esc_url($image_url); ?>" data-ratio="<?php echo esc_html($ratio) ?>" alt="<?php echo esc_html($slide_title); ?>" />
          </a>

        <?php endwhile; ?>

    	</div>
    </div>

    <script type="text/javascript">
    	( function( $ ) {
    		$(document).ready(function() {

    		  var owl = $(".owl-autoplay");
    		  owl.owlCarousel({
    				autoPlay : 6000,
    		    navigation : false,
    				pagination: false,
    		    singleItem : true,
            loop : true,
    		    transitionStyle : "fade"
    		  });

    		});
    	} )( jQuery );
    </script>

  <?php }
}

/* ----------------------------------------------------- */
/* Nav Menu */
/* ----------------------------------------------------- */

class Nav_Walker extends Walker_Nav_Menu {
  function start_lvl(&$output, $depth = 0, $args = array()) {
    $indent = str_repeat("\t", $depth);
    //$output .= "$indent<ul class=\"sub-menu\">\n";
    $output .= "$indent<ul class=\"sub-menu\"><span class=\"sub-menu-holder\">\n";
  }
  function end_lvl(&$output, $depth = 0, $args = array()) {
    //$output .= "</ul>\n";
    $output .= "</span></ul>\n";
  }
}

class manggis_SplitMenuWalker extends Walker_Nav_Menu {

  private $split_at;
  private $button;
  private $count = 0;
  private $wrappedOutput;
  private $replaceTarget;
  private $wrapped = false;
  private $toSplit = false;

  public function __construct($split_at = 5, $button = '<a href="#" class="menu-overflowed">&hellip;</a>') {
    $this->split_at = $split_at;
    $this->button = $button;
  }

  public function walk($elements, $max_depth, ...$args) {
    $args = array_slice(func_get_args(), 2);
    $output = parent::walk($elements, $max_depth, reset($args));
    return $this->toSplit ? $output.'</ul></li>' : $output;
  }

  public function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0 ) {
    $this->count += $depth === 0 ? 1 : 0;
    parent::start_el($output, $item, $depth, $args, $id);
    if (($this->count === $this->split_at) && ! $this->wrapped) {
      $this->wrapped = true;
      $this->replaceTarget = $output;
      $this->wrappedOutput = $this->wrappedOutput($output, $depth);
    } elseif (($this->count === $this->split_at + 1) && ! $this->toSplit) {
      $this->toSplit = true;
      $output = str_replace($this->replaceTarget, $this->wrappedOutput, $output);
    }
  }

  public function start_lvl(&$output, $depth = 0, $args = array()) {
    $indent = str_repeat("\t", $depth);
    //$output .= "$indent<ul class=\"sub-menu\">\n";
    $output .= "$indent<ul class=\"sub-menu\"><span class=\"sub-menu-holder\">\n";
  }

  public function end_lvl(&$output, $depth = 0, $args = array()) {
    //$output .= "</ul>\n";
    $output .= "</span></ul>\n";
  }

  private function wrappedOutput($output, $depth) {
    $dom = new DOMDocument;
    $dom->loadHTML($output.'</li>');
    $lis = $dom->getElementsByTagName('li');
    $last = trim(substr($dom->saveHTML($lis->item($lis->length-1)), 0, -5));
    $wrappedOutput = substr(trim($output), 0, -1 * strlen($last));
    $classes = array(
     'menu-item',
     'menu-item-type-custom',
     'menu-item-object-custom',
     'menu-item-has-children',
     'menu-item-split-wrapper'
    );

    $sub_item = ($depth > 0) ? 'sub-' : '';
    $wrappedOutput .= '<li class="' . $sub_item . implode(' ', $classes).'">';
    $wrappedOutput .= $this->button;
    return $wrappedOutput . '<ul class="sub-menu">'. $last;
  }
}

/* ----------------------------------------------------- */
/* Gallery Setup */
/* ----------------------------------------------------- */

add_filter( 'use_default_gallery_style', '__return_false' );
add_filter( 'the_content', 'manggis_im_add_rel_attribute');
add_filter( 'wp_get_attachment_link', 'manggis_rc_add_rel_attribute');

function manggis_rc_add_rel_attribute($link) {
	return str_replace('<a href', '<a data-fancybox="group" href', $link);
}

function manggis_im_add_rel_attribute($content) {
	$string = '/<a href="(.*?).(jpg|jpeg|png|gif|bmp|ico)"><img(.*?)class="(.*?)wp-image-(.*?)" \/><\/a>/i';
	preg_match_all( $string, $content, $matches, PREG_SET_ORDER);

	foreach ($matches as $val) {
		$post = get_post($val[5]);
		$slimbox_caption = (isset($post->post_content)) ? esc_attr( $post->post_content ) : "";
		$string = '<a href="' . $val[1] . '.' . $val[2] . '"><img' . $val[3] . 'class="' . $val[4] . 'wp-image-' . $val[5] . '" /></a>';
		$replace = '<a data-fancybox="group" href="' . $val[1] . '.' . $val[2] . '" ><img' . $val[3] . 'class="' . $val[4] . 'wp-image-' . $val[5] . '" /></a>';
		$content = str_replace( $string, $replace, $content);
	}

	return $content;
}

add_filter('img_caption_shortcode', 'manggis_fix_img_caption_shortcode', 10, 3);

function manggis_fix_img_caption_shortcode($val, $attr, $content = null) {
  extract(shortcode_atts(array(
    'id'    => '',
    'align' => '',
    'width' => '',
    'caption' => ''
  ), $attr));

  if ( 1 > (int) $width || empty($caption) ) return $val;

  return '<div id="' . esc_html($id) . '" class="wp-caption ' . esc_attr($align) . '" style="width: ' . (0 + (int) $width) . 'px">' . do_shortcode( $content ) . '<p class="wp-caption-text">' . $caption . '</p></div>';
}

/* ----------------------------------------------------- */
/* Social icons in Header */
/* ----------------------------------------------------- */

function manggis_header_social() { ?>
  <?php if ( function_exists('ot_get_option') && ot_get_option('header_social') ) { ?>
    <div class="three columns">
      <div class="header-sidebar widget-themeworm_social">
        <?php if ( function_exists('is_shop') && ot_get_option('woo_cart_icon') == 'all-pages' ) {
          manggis_wc_cart_count();
        } elseif ( function_exists('is_shop') && ot_get_option('woo_cart_icon') == 'shop-pages' && (get_post_type( get_the_ID() ) == 'product' || is_woocommerce() || is_cart() || is_checkout()) ) {
          manggis_wc_cart_count();
        } ?>
        <?php if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) && !is_cart() && !is_checkout() ) { ?>
          <div id="minicart_header" class="minicart-header widget_shopping_cart">
            <?php woocommerce_mini_cart(); ?>
          </div>
        <?php } ?>
        <div class="social-widget-inner">

          <?php	$links_array = ot_get_option('header_social');
          if ( !empty($links_array) ) {
            foreach ( $links_array as $links ) {
              if ( $links['href'] ) {

                if ( $links['name'] == 'GooglePlus' || $links['name'] == 'Google+' ) { $links['name'] = 'google-plus'; }
                if ( $links['name'] == 'VK.com' ) { $links['name'] = 'vk'; }
                if ( empty($links['title']) ) { $links['title'] = $links['name']; }	?>

                <a href="<?php echo esc_url($links['href']); ?>" target="_blank" title="<?php echo esc_attr($links['title']); ?>" >
                  <i class="fa fa-<?php echo esc_attr(strtolower($links['name'])); ?>"></i>
                </a>

              <?php	}
            }
          } ?>

        </div>
      </div>
    </div>
  <?php } ?>
<?php }

/* ----------------------------------------------------- */
/* User Custom Fields */
/* ----------------------------------------------------- */

add_action( 'show_user_profile', 'manggis_add_extra_social_links' );
add_action( 'edit_user_profile', 'manggis_add_extra_social_links' );

function manggis_add_extra_social_links( $user ) { ?>
  <h3><?php esc_html_e('User Profile Links', 'manggis') ?></h3>
    <table class="form-table">
      <tr>
        <th><label for="facebook_profile"><?php esc_html_e('Facebook', 'manggis') ?></label></th>
        <td><input type="text" name="facebook_profile" value="<?php echo esc_attr(get_the_author_meta( 'facebook_profile', $user->ID )); ?>" class="regular-text" /></td>
      </tr>
      <tr>
        <th><label for="twitter_profile"><?php esc_html_e('Twitter', 'manggis') ?></label></th>
        <td><input type="text" name="twitter_profile" value="<?php echo esc_attr(get_the_author_meta( 'twitter_profile', $user->ID )); ?>" class="regular-text" /></td>
      </tr>
      <tr>
        <th><label for="google_profile"><?php esc_html_e('Google+', 'manggis') ?></label></th>
        <td><input type="text" name="google_profile" value="<?php echo esc_attr(get_the_author_meta( 'google_profile', $user->ID )); ?>" class="regular-text" /></td>
      </tr>
			<tr>
        <th><label for="instagram_profile"><?php esc_html_e('Instagram', 'manggis') ?></label></th>
        <td><input type="text" name="instagram_profile" value="<?php echo esc_attr(get_the_author_meta( 'instagram_profile', $user->ID )); ?>" class="regular-text" /></td>
      </tr>
  </table>
<?php }

add_action( 'personal_options_update', 'manggis_save_extra_social_links' );
add_action( 'edit_user_profile_update', 'manggis_save_extra_social_links' );

function manggis_save_extra_social_links( $user_id ) {
  update_user_meta( $user_id,'facebook_profile', sanitize_text_field( $_POST['facebook_profile'] ) );
  update_user_meta( $user_id,'twitter_profile', sanitize_text_field( $_POST['twitter_profile'] ) );
  update_user_meta( $user_id,'google_profile', sanitize_text_field( $_POST['google_profile'] ) );
	update_user_meta( $user_id,'instagram_profile', sanitize_text_field( $_POST['instagram_profile'] ) );
}

/* ----------------------------------------------------- */
/* Recents Comments */
/* ----------------------------------------------------- */

function manggis_recent_comments($no_comments = 6, $comment_len = 80, $avatar_size = 50) {
	$comments_query = new WP_Comment_Query();
	$comments = $comments_query->query( array( 'number' => $no_comments ) );
	$comm = '';
	if ( $comments ) : foreach ( $comments as $comment ) :
		$comm .= '<a class="dummy-media-object" href="' . esc_url(get_permalink( $comment->comment_post_ID )) . '#comment-' . $comment->comment_ID . '">';
		$comm .= get_avatar( $comment->comment_author_email, $avatar_size );
		$comm .= '<h3><strong>'.get_comment_author( $comment->comment_ID ) . '</strong></h3>' . '<div class="search-comment"><span>' . get_the_title($comment->comment_post_ID) . ':</span>';
		$comm .= '"' . strip_tags( substr( apply_filters( 'get_comment_text', $comment->comment_content ), 0, $comment_len ) ) . '..."</div></a>';
	endforeach; else :
		$comm .= esc_html__('No comments.', 'manggis');
	endif;
	return $comm;
}

/* ----------------------------------------------------- */
/* Related posts */
/* ----------------------------------------------------- */

function manggis_related_posts() {

  global $post;
  $tags = wp_get_post_tags( $post->ID );
  $tag_arr = $link = '';
  $i = 0;

  if ( $tags ) {

    foreach( $tags as $tag ) {
      $tag_arr .= $tag->slug . ',';
    }

    $related_postcount = ( function_exists('ot_get_option') && ot_get_option('related_postcount') ) ? ot_get_option('related_postcount') : 3;

    $args = array(
			'post_type' => 'post',
      'tag' => $tag_arr,
      'posts_per_page' => $related_postcount,
      'post__not_in' => array($post->ID)
    );

    $related_posts = get_posts( $args );

    if ( $related_posts ) {

      echo '<div class="related-posts-title"><h2 id="related-posts">' . esc_html__('Related Posts', 'manggis') . '</h2></div>';
      echo '<div class="related-posts blog-content">';

      foreach ( $related_posts as $post ) : setup_postdata( $post ); $i++;

        if (function_exists('get_post_format') && get_post_format($post->ID) == 'link' ) {
        	$link = get_the_content();
        	$link = strip_tags($link);
        } ?>

        <article class="loop one-third column blog-item type-post status-publish">
          <div class="post-data">
            <div class="post-title">
              <h2>
                <a href="<?php the_permalink(); ?>" rel="bookmark">
                  <?php the_title(); ?>
                </a>
              </h2>
              <div class="date-number"><?php echo '<span>'.get_the_date('M').'</span> '.get_the_date('j, Y'); ?></div>
            </div>

            <div class="author-name"><?php esc_html_e('By', 'manggis'); ?> <span><?php echo get_the_author(); ?></span></div>

            <div class="post-category animated-link">
              <?php foreach((get_the_category()) as $category) {
                echo '<a href="' . get_category_link( $category->cat_ID ) . '">#' . $category->category_nicename . '</a>';
              } ?>
            </div>

            <a href="<?php if ( !empty($link)) { echo esc_url($link); } else { the_permalink(); } ?>" rel="bookmark"></a>

            <div class="post-content">
              <div class="post-description loop-page"><p><?php
              if (get_the_content()) {
    						echo strip_shortcodes(wp_trim_words( get_the_content(), 35 ));
    					}	elseif (function_exists('pb_page_builder')) {
    						pb_page_builder('Text');
    					} ?></p></div>
            </div>

          </div>
        </article>

      <?php endforeach;
    }
  }

	wp_reset_postdata();
  echo '</div>';

}

/* ----------------------------------------------------- */
/* Portfolio and Page class */
/* ----------------------------------------------------- */

function manggis_main_class() {
  $main_class = ( get_post_meta(get_the_ID(), 'manggis_white_content', true) != "off" && get_post_type( get_the_ID() ) != 'portfolio' && !is_archive() && !is_search() && !is_404() && get_post_type( get_the_ID() ) != 'product'
  && !is_page_template('templates/template-blog-simple.php')
  && !is_page_template('templates/template-portfolio2col.php')
  && !is_page_template('templates/template-portfolio2col-masonry.php')
  && !is_page_template('templates/template-portfolio4col.php')
  && !is_page_template('templates/template-portfolio4col-masonry.php')
  && !is_page_template('templates/template-portfolio5col.php')
  && !is_page_template('templates/template-portfolio5col-mixed.php')
  && !is_page_template('templates/template-portfolio5col-masonry.php')
  && !is_page_template('templates/template-portfolio6col.php')
  && !is_page_template('templates/template-portfolio4col-blog.php')
  && !is_page_template('templates/template-portfolio5col-blog.php')
  && !is_page_template('templates/template-portfolio4col-masonry-blog.php')
  && !is_page_template('templates/template-portfolio5col-masonry-blog.php')
  && !is_page_template('templates/template-portfolio6col-masonry.php') ) ? 'white-page' : '';
  $main_class .= ( 'portfolio' == get_post_type( get_the_ID() )  ) ? ' is-portfolio' : '';
  return $main_class;
}

/* ----------------------------------------------------- */
/* Page Title */
/* ----------------------------------------------------- */

function manggis_title() {
  $title = get_the_title();
  global $post;
  $author_id = $post->post_author;
  $thumbnail_url = '';

  $title_class = ( get_post_meta(get_the_ID(), 'manggis_title_height', true) ) ?: 'titleheight-standard';
  $manggis_title_bg = ( get_post_meta(get_the_ID(), 'manggis_title_bg', true) ) ?: '';

  $thumbnail_url = 'background-color:' . esc_html($manggis_title_bg);

  if (has_post_thumbnail() && get_post_type( get_the_ID() ) != "portfolio") {
    $thumbnail_data = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
    $bg_color = ($manggis_title_bg) ?: '#000';
    $thumbnail_url = "background-image:url('" . esc_url($thumbnail_data[0]) . "'); background-color:" . esc_html($bg_color) . ";" ;
  } ?>

  <div class="container title_container <?php echo esc_html($title_class); ?>" style="<?php echo esc_html($thumbnail_url); ?>">

    <div id="page-title">
      <h1><?php echo esc_html($title); ?></h1>

      <?php if ( function_exists('ot_get_option') && ot_get_option('display_portfolio_nav') != "off" && is_single() ) {
    		echo '<div class="project-navigation" role="navigation">';
    		if ( get_adjacent_post( false, '', false ) ) { next_post_link( '%link', '<span>%title</span>' ); }
        if ( get_adjacent_post( false, '', true ) ) { previous_post_link( '%link', '<span>%title</span>' ); }
        echo '</div>';
      } ?>

    </div>

    <?php if ( get_post_type( get_the_ID() ) == "post" ) { ?>
      <div class="post-meta">
        <div class="single-date">
          <span class="single-number"><?php echo get_the_date('M j, Y'); ?></span>/
          <span class="single-author animated-link"><a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID', $author_id ) ); ?>"><?php the_author_meta( 'nickname', $author_id ); ?></a></span>/
          <span class="single-cats animated-link"><?php esc_html_e('in: ', 'manggis'); the_category( ', ' ); ?></span>/
          <span class="single-comments animated-link"><?php esc_html_e('with', 'manggis'); ?>
            <?php  comments_popup_link( esc_html__('no comments','manggis'), esc_html__('1 comment','manggis'), esc_html__('% comments','manggis'), 'comments-link', esc_html__('Comments are off for this post','manggis')); ?>
          </span>
        </div>
      </div>
    <?php } ?>

  </div>
<?php
}

/* ----------------------------------------------------- */
/* Blog Timeline */
/* ----------------------------------------------------- */

function manggis_timeline() { ?>
	<section class="cd-horizontal-timeline">
		<div class="timeline">
			<div class="events-wrapper">
				<div class="events">
					<ol>
						<?php $count_posts = wp_count_posts();

            echo '<li><a href="' . get_permalink() . '" data-page="all" data-posts="' . $count_posts->publish . '" data-date="01/' . date('m/Y', strtotime(get_lastpostdate($timezone = 'blog', $post_type = 'post')) + 2592000) . '" class="selected">' . esc_html__('All', 'manggis') . '</a></li>';

            $month_archives = wp_get_archives(array(
							'type' => 'monthly',
							'post_type' => 'post',
							'show_post_count' => true,
							'echo' => 0,
							'format' => 'html',
              'before'          => '',
            	'after'           => '',
						));

						$month_archives_array = explode("\n", $month_archives);
						foreach ($month_archives_array as $month) {
							if ($month) {
								$url = manggis_get_data($month, "href='", "'>");
								$posts = manggis_get_data(strip_tags($month), "(", ")");
                $data_date = (substr($url, -1, 1) == '/') ? substr($url, -3, 2) . '/' . substr($url, -8, 4) : substr($url, -2, 2) . '/' . substr($url, -6, 4);

                //mb_internal_encoding('utf-8');
                //$show_month = mb_substr(strip_tags($month), 0, 4);
                $dateObj = DateTime::createFromFormat('j,n,Y', '01,' . str_replace('/', ',', esc_attr($data_date)));
								echo '<li><a href="' . esc_url($url) . '"  data-month="' . $dateObj->format('M') . '" data-posts="' . esc_attr($posts) . '" data-date="01/' . esc_attr($data_date) . '" class="">' . $dateObj->format('M') . '</a></li>';
							}
						} ?>
					</ol>
					<span class="filling-line" aria-hidden="true"></span>
				</div>
			</div>
			<ul class="cd-timeline-navigation">
				<li><a href="#0" class="prev inactive"><?php esc_attr_e( 'Prev', 'manggis' ); ?></a></li>
				<li><a href="#0" class="next"><?php esc_attr_e( 'Next', 'manggis' ); ?></a></li>
			</ul>
		</div>
	</section>
<?php }

function manggis_get_data($string, $start, $end) {
  $pos = stripos($string, $start);
  $str = substr($string, $pos);
  $str_two = substr($str, strlen($start));
  $second_pos = stripos($str_two, $end);
  $str_three = substr($str_two, 0, $second_pos);
  $unit = trim($str_three);
  return $unit;
}

/* ----------------------------------------------------- */
/* AJAX loading Posts */
/* ----------------------------------------------------- */

add_action( 'wp_ajax_nopriv_ajax_blog', 'manggis_ajax_blog' );
add_action( 'wp_ajax_ajax_blog', 'manggis_ajax_blog' );

function manggis_ajax_blog() {
	$perpage = esc_attr($_POST['perpage']);
	//$offset = $_POST['offset'];
  // $exclude = esc_attr($_POST['exclude']);
  $exclude = (isset($_POST['exclude'])) ? $_POST['exclude'] : '';
  $category = esc_attr($_POST['category']);
  $tag = esc_attr($_POST['tag']);
  $page = $_POST['page'];
  $month = $_POST['month'];
  $month_num = $_POST['month_num'];
  //$month_num = $_POST['month_num'];
  $month = (isset($month)) ? explode("/", esc_attr($month)) : array();
  $month_num = ($month_num) ? explode("/", esc_attr($month_num)) : array();
  $exclude = (isset($exclude)) ? explode(",", substr( $exclude, 0, -1 )) : array();
  $blog_postsperpage = ( function_exists('ot_get_option') && ot_get_option('blog_postsperpage') ) ? esc_html(ot_get_option('blog_postsperpage')) : get_option('posts_per_page');
  $portfolio_sorting = (function_exists('ot_get_option') && ot_get_option('portfolio_sorting')) ? esc_attr(ot_get_option('portfolio_sorting')) : '';
  $portfolio_order = (function_exists('ot_get_option') && ot_get_option('portfolio_order')) ? esc_attr(ot_get_option('portfolio_order')) : '';
  $date_query = (isset($month) && $month != 'all') ? array( array( 'year'  => esc_attr($month[2]), 'month' => esc_attr($month[1]) )) : '';
  $date_query = (isset($page) || $month == 'all') ? '' : $date_query;
  $date_query = ($month_num) ? array( array( 'year' => esc_attr($month_num[1]), 'month' => esc_attr($month_num[0]) )) : $date_query;

	$args = array(
		'post_type' => 'post',
    'cat' => $category,
    'tag_id' => $tag,
		/*'offset' => $offset,*/
		'posts_per_page' => $blog_postsperpage,
    'post_status' => 'publish',
    'orderby' => $portfolio_sorting,
    'order' => $portfolio_order,
    /*'orderby' => 'none',*/
    'post__not_in' => $exclude,
    'date_query' => $date_query
	);

	$new_blog_query = new WP_Query( $args );

	if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
		if ( $new_blog_query->have_posts() ) :
			while ( $new_blog_query->have_posts() ) : $new_blog_query->the_post();
        get_template_part( '/templates/blog/blog', 'loop' );
			endwhile;
		endif;
	}
	die();
}

/* ----------------------------------------------------- */
/* Load more Blog posts */
/* ----------------------------------------------------- */

function manggis_loadmore_posts( $template = '', $category_id = false, $tag_id = false, $month_num = false ) {
  $columns = 'one-third column';
  $blog_postsperpage = ( function_exists('ot_get_option') && ot_get_option('blog_postsperpage') ) ? esc_html(ot_get_option('blog_postsperpage')) : get_option('posts_per_page');
  $show_more = ( function_exists('ot_get_option') && ot_get_option('infinite_off' ) != 'off' ) ? '&nbsp;' : esc_attr__( 'Show more','manggis' );
  $data_loading = ( function_exists('ot_get_option') && ot_get_option('portfolio_loadmore_animation') != 'off' ) ? '&nbsp;' : esc_attr__( 'Loading...', 'manggis' );
  $count_posts = wp_count_posts();
  $get_category = ( $category_id ) ? get_term_by( 'id', $category_id, 'category') : false;
  $get_tag = ( $tag_id ) ? get_term_by( 'id', $tag_id, 'post_tag') : false;
  $get_month = ( $month_num ) ? explode("/", esc_attr($month_num)) : array();
  $load_svg = get_template_directory_uri() . '/assets/images/three-dots.svg';

  $data_all = ( $category_id ) ? $get_category->count : $count_posts->publish;
  $data_all = ( $tag_id ) ? $get_tag->count : $data_all;
  $the_query = ( $month_num ) ? new WP_Query( array( 'year' => $get_month[1], 'monthnum' => $get_month[0] ) ) : array();
  $data_all = ( $month_num ) ? $the_query->post_count : $data_all;

  echo '<div class="load-more ' . esc_attr($template) . '">';
  if ( function_exists('ot_get_option') && ot_get_option('portfolio_loadmore_animation') != 'off' && ot_get_option('portfolio_loadmore_animation' ) != 'off') {
    echo '<img class="loadmore-img" src="'. esc_url($load_svg) . '" alt="' . esc_attr__( "Show more", "manggis" ) . '" />';
  }
  echo '<a href="#" id="next-posts" data-month="' . esc_attr($month_num) . '" data-tag="' . esc_attr($tag_id) . '" data-cat="' . esc_attr($category_id) . '" data-perpage="'. esc_attr($blog_postsperpage) .'" data-all="' . esc_attr($data_all) . '" data-load="' . esc_attr($show_more) . '" data-loading="' . esc_attr($data_loading) . '" data-columns="'. esc_attr($columns) .'">';
  echo esc_attr($show_more)
    . '</a>'
    . '</div>';
}

/* ----------------------------------------------------- */
/* Infinite AJAX loading portfolio and filtering */
/* ----------------------------------------------------- */

add_action( 'wp_ajax_nopriv_ajax_infinite', 'ajax_infinite' );
add_action( 'wp_ajax_ajax_infinite', 'ajax_infinite' );

function ajax_infinite() {
	$perpage = $_POST['perpage'];
	//$offset = $_POST['offset'];
	$filter = $_POST['filter'];
  $style = ($_POST['style']) ?: '';
  global $columns, $enable_mixed;
  $columns = $_POST['columns'];
  // $exclude = $_POST['exclude'];
  $exclude = (isset($_POST['exclude'])) ? $_POST['exclude'] : '';
  $exclude = (isset($exclude)) ? explode(",", substr( $exclude, 0, -1 )) : '';
  $filter = ( $filter != 'all' ) ? explode(",", $filter) : $filter;
	$tax_query = ( $filter != 'all' ) ? array( array( 'taxonomy' => 'filters', 'field' => 'slug', 'terms' => $filter, 'operator' => 'IN' ) ) : '';

  if ( $style == 'enable_mixed' ) { $enable_mixed = true; }

	$args = array(
		'post_type' => 'portfolio',
		//'offset' => $offset,
		'posts_per_page' => $perpage,
    'post_status' => 'publish',
    'post__not_in' => $exclude,
		'tax_query' => $tax_query,
    // 'meta_query' => array( array(
		// 	'key' => '_thumbnail_id',
		// 	'compare' => 'EXISTS'
		// ))
	);

	$portfolio_query = new WP_Query( $args );

	if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
		if ( $portfolio_query->have_posts() ) :
			while ( $portfolio_query->have_posts() ) : $portfolio_query->the_post();
        if ( !post_password_required() ) {
          if ($style == 'masonry') {
            get_template_part( '/templates/content/content', 'loop-masonry' );
          } else {
            get_template_part( '/templates/content/content', 'loop' );
          }
          $exclude[] = get_the_ID();
        }
			endwhile;
		endif;
	}
	die();
}

/* ----------------------------------------------------- */
/* load more portfolio */
/* ----------------------------------------------------- */

function manggis_load_more( $filters_array = '', $columns = 'one-third column', $data_all = false, $posts_per_page = false ) {

  global $masonry, $enable_mixed;

  $posts_per_page = (!empty($posts_per_page)) ? $posts_per_page : ot_get_option('portfolio_showpost','6');
  $show_more = ( function_exists('ot_get_option') && ot_get_option('infinite_off' ) != 'off' ) ? '&nbsp;' : esc_attr__( 'Show more','manggis' );
  $data_loading = ( function_exists('ot_get_option') && ot_get_option('portfolio_loadmore_animation') != 'off' ) ? '&nbsp;' : esc_attr__( 'Loading...', 'manggis' );
  $load_svg = get_template_directory_uri() . '/assets/images/three-dots.svg';
  $data_all = (!empty($data_all)) ? $data_all : manggis_get_tax_filters($filters_array, 'count');
  $portfolio_style = ($masonry) ? 'masonry' : '';
  $portfolio_style = ($enable_mixed) ? 'enable_mixed' : $portfolio_style;

  echo '<div class="load-more">';
  if ( function_exists('ot_get_option') && ot_get_option('portfolio_loadmore_animation') != 'off' && ot_get_option('portfolio_loadmore_animation' ) != 'off') {
    echo '<img class="loadmore-img" src="'. $load_svg . '" alt="' . esc_attr__( "Show more", "manggis" ) . '" />';
  }
  echo '<a href="#" id="next-projects" data-style="' . esc_html($portfolio_style) . '" data-all="'. esc_html($data_all) .'" data-perpage="'. esc_html($posts_per_page) .'" data-filter="'. manggis_get_tax_filters($filters_array) .'" data-load="' . $show_more . '" data-loading="' . $data_loading . '" data-columns="'. $columns .'">';
  echo esc_html($show_more)
    . '</a>'
    . '</div>';
}

function manggis_get_appear( $selector = '.load-more', $container = '#next-projects' ) {
print <<<END
  <script type="text/javascript">
    jQuery(document).ready(function() {
      jQuery('$selector').appear();
      jQuery(document.body).on('appear', '$selector', function() {
        if ( jQuery( '$container' ).data( 'perpage' ) < jQuery( '$container' ).attr( 'data-all' ) ) {
          jQuery( '$container' ).click();
        }
      });
    });
  </script>
END;
}

function manggis_get_tax_filters( $filters_array, $count = '' ) {
  $tax_filters = ''; $tax_count = 0;

  if (is_array( $filters_array )) {
  	foreach ( $filters_array as $filter ) {
  		$term = get_term( $filter, 'filters' );
  		if ($term) { $tax_filters .= $term->slug .","; }
  		//$tax_count = $term->count + $tax_count;
  	}
  	$tax_filters = substr( $tax_filters, 0, -1 );

    $query = new WP_Query( array(
    	'post_type' => 'portfolio',
    	'tax_query' => array(	array(
    			'taxonomy' => 'filters',
    			'field'    => 'slug',
    			'terms'    => explode( ",", $tax_filters ),
    	))
    ));

    $tax_count = $query->found_posts;
  }

  $filters = ( $tax_filters ) ? $tax_filters : 'all';
  $data_all = ( $tax_count > 0 ) ? $tax_count : wp_count_posts( 'portfolio' )->publish;

  return $output = ( 'count' == $count ) ? $data_all : $filters;
}

/* ----------------------------------------------------- */
/* Portfolio Info */
/* ----------------------------------------------------- */

function manggis_portfolio_info() {
  $manggis_info_desc = get_post_meta(get_the_ID(), 'manggis_info_desc', true);
  $manggis_info_title = get_post_meta(get_the_ID(), 'manggis_info_title', true);
  $manggis_project_client = get_post_meta(get_the_ID(), 'manggis_project_client', true);
  $manggis_project_date = get_post_meta(get_the_ID(), 'manggis_project_date', true);
  $manggis_project_website_url = get_post_meta(get_the_ID(), 'manggis_project_website_url', true);
  $manggis_project_website = get_post_meta(get_the_ID(), 'manggis_project_website', true);
  $manggis_project_date = get_post_meta(get_the_ID(), 'manggis_project_date', true);
  $manggis_info_position = get_post_meta(get_the_ID(), 'manggis_info_position', true);
  $manggis_project_category = '';
  global $manggis_shared;
  $manggis_shared = false;

  $terms = get_the_terms( get_the_ID(), 'filters');
  if ( $terms ) {
    foreach ( $terms as $term ) {
      $manggis_project_category .= esc_html($term->name) . ' ';
    }
  }

  if ( $manggis_info_desc || $manggis_info_title || $manggis_project_client || $manggis_project_date ) { ?>
    <div class="portfolio-info <?php echo esc_html($manggis_info_position); ?>">
    <div class="horisontal-divider-left">
      <?php if ( $manggis_info_title ) { ?>
        <h3><?php echo esc_html($manggis_info_title); ?></h3>
      <?php } ?>
      <?php if ( $manggis_info_desc ) { ?>
        <p><?php echo esc_html($manggis_info_desc); ?></p>
      <?php } ?>
      </div>
      <div class="horisontal-divider-right">
      <?php if ( $manggis_project_website_url ) { ?>
        <a href="<?php echo esc_url($manggis_project_website_url); ?>" target="_blank" class="cd-btn"><?php echo esc_html($project_website = ($manggis_project_website) ?: esc_attr__( 'View website','manggis' )); ?></a>
      <?php } ?>
      <?php if ( $manggis_project_client ) { ?>
        <div class="info-client"><span><?php echo esc_attr__( 'Client:','manggis' ) . '</span>' . esc_html($manggis_project_client); ?></div>
      <?php } ?>
      <?php if ( get_post_meta(get_the_ID(), 'manggis_show_category', true) != 'off' && $manggis_project_category ) { ?>
        <div class="info-category"><span><?php echo esc_attr__( 'Category:','manggis' ) . '</span>' . esc_html($manggis_project_category); ?></div>
      <?php } ?>
      <?php if ( get_post_meta(get_the_ID(), 'manggis_show_date', true) != 'off' ) { ?>
        <div class="info-date"><span><?php echo esc_attr__( 'Date:','manggis' ) . '</span>' . esc_html($manggis_project_date = ($manggis_project_date) ? date('F d, Y', strtotime($manggis_project_date)) : get_the_date() ); ?></div>
      <?php }
      if ( get_post_meta(get_the_ID(), 'manggis_show_share', true) != 'off' ) {
        /*manggis_share_me(); $manggis_shared = true;*/
      } ?>
    </div>
    </div>
  <?php }
}

/* ----------------------------------------------------- */
/* Social Share in posts/portfolio */
/* ----------------------------------------------------- */

function manggis_share() {
  $manggis_shared = new manggis_GetGlobal();
  $show_share = ( get_post_type( get_the_ID() ) == "post" ) ? false : $manggis_shared->manggis_shared;

if ( function_exists('ot_get_option') && ot_get_option('portfolio_share_on') != 'off' && get_post_meta(get_the_ID(), 'manggis_show_share', true) != 'off' /*&& false === $show_share*/ ) {
    if ( !get_post_meta(get_the_ID(), 'manggis_info_desc', true) || !get_post_meta(get_the_ID(), 'manggis_info_title', true) || !get_post_meta(get_the_ID(), 'manggis_project_client', true) || !get_post_meta(get_the_ID(), 'manggis_project_date', true) ) { ?>
      <div class="portfolio-share">
        <?php manggis_share_me(); ?>
      </div>
    <?php }
  } elseif ( !function_exists('ot_get_option') ) { ?>
    <div class="portfolio-share">
      <?php manggis_share_me(); ?>
    </div>
  <?php }
}

function manggis_share_me() { ?>
  <div class="post-share">
    <?php esc_html_e( 'Share:', 'manggis' ); ?>
    <a href="https://twitter.com/intent/tweet?text=<?php the_title(); ?>+<?php the_permalink(); ?>" class="fa fa-twitter" target="_blank"></a>
    <a href="https://www.facebook.com/share.php?u=<?php the_permalink(); ?>&title=<?php the_title(); ?>" class="fa fa-facebook" target="_blank"></a>
    <!--<a href="https://plus.google.com/share?url=<?php the_permalink(); ?>" class="fa fa-google-plus" target="_blank"></a>-->
    <?php $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' ); $thumbnail_url = isset($pinterestimage[0]) ? $pinterestimage[0] : ''; ?>
    <a href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&media=<?php echo esc_url($thumbnail_url); ?>&description=<?php the_title(); ?>" class="fa fa-pinterest-p" target="_blank"></a>
  </div>
<?php }

/* ----------------------------------------------------- */
/* Output Map in Contacts Page */
/* ----------------------------------------------------- */

function manggis_contact_map( $param = false ) {
  $map_address = ( function_exists('ot_get_option') && ot_get_option('map_address') && ot_get_option('map_on') != 'off' ) ? esc_html(ot_get_option('map_address')) : '';
  $map_height = ( function_exists('ot_get_option') && ot_get_option('map_height') ) ? ot_get_option('map_height') : '';

  if ( $map_address ) {
  	$mapID = rand (1, 999);
  	$prepAddr = esc_attr( str_replace(' ', '+', $map_address) );
  	$geocode = wp_remote_fopen('http://maps.google.com/maps/api/geocode/json?address='. $prepAddr .'&sensor=false');
  	$output = json_decode($geocode);

    $google_latitude = ( $map_address && isset($output->results[0]) ) ? esc_attr($output->results[0]->geometry->location->lat) : '40.706078';
    $google_longitude = ( $map_address && isset($output->results[0]) ) ? esc_attr($output->results[0]->geometry->location->lng) : '-74.016578';

    $google_latitude = ( function_exists('ot_get_option') && ot_get_option('map_lat') ) ? esc_attr(ot_get_option('map_lat')) : $google_latitude;
    $google_longitude = ( function_exists('ot_get_option') && ot_get_option('map_lon') ) ? esc_attr(ot_get_option('map_lon')) : $google_longitude;

    $output = '<div id="googlemaps-ID1" class="google-map map_height-' . esc_html($map_height) . '" data-map="' . esc_html($prepAddr) . '"></div>';

  	return $output = ($param) ? "var latitude = " . $google_latitude . ", longitude = " . $google_longitude : $output;
  }
}

function manggis_map_init() {
  if ( is_page_template("templates/template-contact.php") && function_exists('ot_get_option') && ot_get_option('map_address') && ot_get_option('map_on') != 'off' ) {
    $map_key = ( function_exists('ot_get_option') && ot_get_option('map_key') ) ? esc_attr(ot_get_option('map_key')) : '';
    wp_enqueue_script( 'maps', 'https://maps.googleapis.com/maps/api/js?key=' . $map_key . '&libraries=geometry', 'jquery', '2.1', true );
    wp_enqueue_script( 'maplace', get_template_directory_uri() . '/assets/js/maplace.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'googlemap', get_template_directory_uri() . '/assets/js/googlemap.min.js', array( 'jquery' ), false, true );
    wp_add_inline_script ( 'googlemap', manggis_contact_map('coordinates'), 'before');
  }
}

add_action( 'wp_enqueue_scripts', 'manggis_map_init' );

/* ----------------------------------------------------- */
/* HEX to RGBA color */
/* ----------------------------------------------------- */

function manggis_hex2rgba($color, $opacity = false) {

  $default = 'rgb(0,0,0)';
  if ( empty($color) ) return $default;
  if ( $color[0] == '#' ) {
    $color = substr( $color, 1 );
  }

  if ( strlen($color) == 6 ) {
    $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
  } elseif ( strlen( $color ) == 3 ) {
    $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
  } else {
    return $default;
  }

  $rgb =  array_map('hexdec', $hex);

  if ( $opacity ) {
    if ( abs($opacity) > 1 )
    $opacity = 1.0;
    $output = ''.implode(",",$rgb).','.$opacity.'';
  } else {
    $output = ''.implode(",",$rgb).'';
  }

  return esc_html($output);
}

/* ----------------------------------------------------- */
/* TGM */
/* ----------------------------------------------------- */

require_once get_template_directory() . '/plugins/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'manggis_register_required_plugins' );

if (!function_exists('manggis_register_required_plugins')) {
function manggis_register_required_plugins() {

	$plugins = array(
		array(
			'name'               => 'Portfolio Installer', // The plugin name.
			'slug'               => 'portfolio-installer', // The plugin slug (typically the folder name).
			'source'             => get_template_directory() . '/plugins/portfolio-installer.zip', // The plugin source.
			'required'           => true, // If false, the plugin is only 'recommended' instead of required.
			'version'            => '2.1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
			'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			'external_url'       => '', // If set, overrides default API URL and points to an external URL.
		),
    array(
			'name'               => esc_html__('OptionTree', 'manggis'),
			'slug'               => 'option-tree',
      'source'             => get_template_directory() . '/plugins/option-tree.zip',
			'required'           => true,
			'version'            => '2.7.0',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => ''
		),
    // array(
		// 	'name'               => 'Page builder by Mallini',
		// 	'slug'               => 'themeworm-pagebuilder',
    //   'source'             => get_template_directory() . '/plugins/themeworm-pagebuilder.zip',
		// 	'required'           => false,
		// 	'version'            => '3.0',
		// 	'force_activation'   => false,
		// 	'force_deactivation' => false,
		// 	'external_url'       => ''
		// ),
		array(
			'name'               => 'Contact Form 7',
			'slug'               => 'contact-form-7',
			'required'           => false,
			'version'            => '5.0',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => ''
		)

	);

  $config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to pre-packaged plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => true,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
		'strings'      => array(
			'page_title'                      => esc_html__( 'Install Required Plugins', 'manggis' ),
			'menu_title'                      => esc_html__( 'Install Plugins', 'manggis' ),
			'installing'                      => esc_html__( 'Installing Plugin: %s', 'manggis' ), // %s = plugin name.
			'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'manggis' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop(
				'Sorry, but you do not have the correct permissions to install the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to install the %1$s plugins.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_ask_to_update_maybe'      => _n_noop(
				'There is an update available for: %1$s.',
				'There are updates available for the following plugins: %1$s.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop(
				'Sorry, but you do not have the correct permissions to update the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to update the %1$s plugins.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'manggis'
			), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop(
				'Sorry, but you do not have the correct permissions to activate the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to activate the %1$s plugins.',
				'manggis'
			), // %1$s = plugin name(s).
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'manggis'
			),
			'update_link' 					  => _n_noop(
				'Begin updating plugin',
				'Begin updating plugins',
				'manggis'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'manggis'
			),
			'return'                          => esc_html__( 'Return to Required Plugins Installer', 'manggis' ),
			'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'manggis' ),
			'activated_successfully'          => esc_html__( 'The following plugin was activated successfully:', 'manggis' ),
			'plugin_already_active'           => esc_html__( 'No action taken. Plugin %1$s was already active.', 'manggis' ),  // %1$s = plugin name(s).
			'plugin_needs_higher_version'     => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'manggis' ),  // %1$s = plugin name(s).
			'complete'                        => esc_html__( 'All plugins installed and activated successfully. %1$s', 'manggis' ), // %s = dashboard link.
			'contact_admin'                   => esc_html__( 'Please contact the administrator of this site for help.', 'manggis' ),

			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		)
	);

	tgmpa( $plugins, $config );

} }

?>

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328900&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        